Turn wait_on_page_locked() and wait_on_page_locked_killable() into
wrappers.  This eliminates a call to compound_head() from each call-site,
reducing text size by 207 bytes for me.

Signed-off-by: Matthew Wilcox (Oracle) <wi...@infradead.org>
---
 include/linux/pagemap.h | 26 ++++++++++++++++++--------
 mm/filemap.c            |  4 ++--
 2 files changed, 20 insertions(+), 10 deletions(-)

diff --git a/mm/filemap.c b/mm/filemap.c
index e25a5ebc914c..50263fa62574 100644
--- a/mm/filemap.c
+++ b/mm/filemap.c
@@ -1559,9 +1559,9 @@ int __lock_page_or_retry(struct page *page, struct 
mm_struct *mm,
 
                mmap_read_unlock(mm);
                if (flags & FAULT_FLAG_KILLABLE)
-                       wait_on_page_locked_killable(page);
+                       wait_on_folio_locked_killable(folio);
                else
-                       wait_on_page_locked(page);
+                       wait_on_folio_locked(folio);
                return 0;
        }
        if (flags & FAULT_FLAG_KILLABLE) {
diff --git a/include/linux/pagemap.h b/include/linux/pagemap.h
index e7fe8b276a2d..c53743f24550 100644
--- a/include/linux/pagemap.h
+++ b/include/linux/pagemap.h
@@ -732,23 +732,33 @@ extern void wait_on_page_bit(struct page *page, int 
bit_nr);
 extern int wait_on_page_bit_killable(struct page *page, int bit_nr);
 
 /* 
  * Wait for a page to be unlocked.
  *
  * This must be called with the caller "holding" the page,
  * ie with increased "page->count" so that the page won't
  * go away during the wait..
  */
+static inline void wait_on_folio_locked(struct folio *folio)
+{
+       if (FolioLocked(folio))
+               wait_on_page_bit(&folio->page, PG_locked);
+}
+
+static inline int wait_on_folio_locked_killable(struct folio *folio)
+{
+       if (!FolioLocked(folio))
+               return 0;
+       return wait_on_page_bit_killable(&folio->page, PG_locked);
+}
+
 static inline void wait_on_page_locked(struct page *page)
 {
-       if (PageLocked(page))
-               wait_on_page_bit(compound_head(page), PG_locked);
+       wait_on_folio_locked(page_folio(page));
 }
 
 static inline int wait_on_page_locked_killable(struct page *page)
 {
-       if (!PageLocked(page))
-               return 0;
-       return wait_on_page_bit_killable(compound_head(page), PG_locked);
+       return wait_on_folio_locked_killable(page_folio(page));
 }
 
 int put_and_wait_on_page_locked(struct page *page, int state);
@@ -732,23 +732,33 @@ extern void wait_on_page_bit(struct page *page, int 
 
 /* 
- * Wait for a page to be unlocked.
+ * Wait for a folio to be unlocked.
  *
@@ -732,23 +732,33 @@ extern void wait_on_page_bit(struct page *page, int 
  *
- * This must be called with the caller "holding" the page,
- * ie with increased "page->count" so that the page won't
+ * This must be called with the caller "holding" the folio,
+ * ie with increased "page->count" so that the folio won't
  * go away during the wait..
  */
-- 
2.30.0

Reply via email to